import { scatterPlot } from './scatterPlot.js';

const csvUrl =
  'https://gist.githubusercontent.com/sriramofficial9/e62b48a21988996d62fb6854f135b66e/raw/e78541fe031100c1f75273cbcf4e13bd043f0fca/titanic.csv';
const parseRow = (d) => {
  d.Age = +d.Age;
  d.Fare = +d.Fare;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;

const svg = d3
  .select('#scatterplot')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  const data = await d3.csv(csvUrl, parseRow);

  // Split the data into two halves for separate visualization.
  const firstHalfData = data.filter(
    (d, i) => i < data.length / 2,
  );
  const secondHalfData = data.filter(
    (d, i) => i >= data.length / 2,
  );

  const scatterPlot1 = scatterPlot()
    .width(width)
    .height(height / 2)
    .xValue((d) => d.Age)
    .yValue((d) => d.Fare)
    .colorValue((d) => d.Sex)
    .margin({ top: 20, right: 20, bottom: 40, left: 50 })
    .radius(5);

  const scatterPlot2 = scatterPlot()
    .width(width)
    .height(height / 2)
    .xValue((d) => d.Age)
    .yValue((d) => d.Fare)
    .colorValue((d) => d.Sex)
    .margin({ top: 20, right: 20, bottom: 40, left: 50 })
    .radius(5);

  let currentPlot = 1;

  const update = () => {
    // Remove all existing elements in the SVG to prepare for the new plots.
    svg.selectAll('*').remove();

    // Conditional logic to switch between plot1 and plot2.
    if (currentPlot === 1) {
      scatterPlot1.data(firstHalfData);
      svg.call(scatterPlot1);
      currentPlot = 2;
    } else {
      scatterPlot2.data(secondHalfData);
      svg.call(scatterPlot2);
      currentPlot = 1;
    }
  };

  update();

  // Set an interval to automatically update the plot every 5 seconds.
  setInterval(update, 5000);
};

main();
